@@ -53,22 +53,17 @@ class MapUnitCache(private val mapUnit: MapUnit) {
     val doubleMovementInTerrain = HashMap<String, DoubleMovement>()
 
     var canEnterIceTiles = false
-
     var cannotEnterOceanTiles = false
-
     var canEnterForeignTerrain: Boolean = false
-
+    var canEnterCityStates: Boolean = false
     var costToDisembark: Float? = null
-
     var costToEmbark: Float? = null
-
     var paradropRange = 0
 
     var hasUniqueToBuildImprovements = false    // not canBuildImprovements to avoid confusion
     var hasUniqueToCreateWaterImprovements = false
 
     var hasStrengthBonusInRadiusUnique = false
-
     var hasCitadelPlacementUnique = false
 
     fun updateUniques() {
@@ -119,6 +114,8 @@ class MapUnitCache(private val mapUnit: MapUnit) {
         canEnterForeignTerrain = mapUnit.hasUnique(UniqueType.CanEnterForeignTiles)
                 || mapUnit.hasUnique(UniqueType.CanEnterForeignTilesButLosesReligiousStrength)
 
+        canEnterCityStates = mapUnit.hasUnique(UniqueType.CanTradeWithCityStateForGoldAndInfluence)
+
         hasStrengthBonusInRadiusUnique = mapUnit.hasUnique(UniqueType.StrengthBonusInRadius)
         hasCitadelPlacementUnique = mapUnit.getMatchingUniques(UniqueType.ConstructImprovementInstantly)
             .mapNotNull { mapUnit.civ.gameInfo.ruleset.tileImprovements[it.params[0]] }
