@@ -177,11 +177,11 @@ class CityStateDiplomacyTable(private val diplomacyScreen: DiplomacyScreen) {
         }
 
         fun getBonusText(header: String, level: RelationshipLevel): String {
-            val boni = viewingCiv.cityStateFunctions
+            val bonuses = viewingCiv.cityStateFunctions
                 .getCityStateBonuses(otherCiv.cityStateType, level)
                 .filterNot { it.isHiddenToUsers() }
-            if (boni.none()) return ""
-            return (sequenceOf(header) + boni.map { it.text }).joinToString(separator = "\n") { it.tr() }
+            if (bonuses.none()) return ""
+            return (sequenceOf(header) + bonuses.map { it.text }).joinToString(separator = "\n") { it.tr() }
         }
         fun addBonusLabel(header: String, bonusLevel: RelationshipLevel, relationLevel: RelationshipLevel) {
             val bonusLabelColor = if (relationLevel == bonusLevel) Color.GREEN else Color.GRAY
