@@ -22,9 +22,9 @@ import com.unciv.logic.trade.TradeType.WarDeclaration
 import com.unciv.logic.trade.TradeType.values
 import com.unciv.models.ruleset.tile.ResourceSupplyList
 import com.unciv.models.translations.tr
-import com.unciv.ui.components.widgets.ExpanderTab
 import com.unciv.ui.components.extensions.disable
 import com.unciv.ui.components.input.onClick
+import com.unciv.ui.components.widgets.ExpanderTab
 import com.unciv.ui.images.IconTextButton
 import com.unciv.ui.images.ImageGetter
 import com.unciv.ui.screens.basescreen.BaseScreen
@@ -45,6 +45,11 @@ class OffersListScroll(
 
     private val expanderTabs = HashMap<TradeType, ExpanderTab>()
 
+    init {
+        fadeScrollBars=false
+        setScrollbarsVisible(true)
+    }
+
     /**
      * @param offersToDisplay The offers which should be displayed as buttons
      * @param otherOffers The list of other side's offers to compare with whether these offers are unique
@@ -61,7 +66,7 @@ class OffersListScroll(
         expanderTabs.clear()
 
         for (offerType in values()) {
-            val labelName = when(offerType){
+            val labelName = when(offerType) {
                 Gold, Gold_Per_Turn, Treaty, Agreement, Introduction -> ""
                 Luxury_Resource -> "Luxury resources"
                 Strategic_Resource -> "Strategic resources"
