@@ -1,15 +1,6 @@
 import com.unciv.build.BuildConfig
 import org.gradle.api.tasks.testing.logging.TestLogEvent
 
-plugins {
-    id("java")
-}
-
-java {
-    sourceCompatibility = JavaVersion.VERSION_1_8
-    targetCompatibility = JavaVersion.VERSION_1_8
-}
-
 tasks {
     test {
         workingDir = file("../android/assets")
