@@ -117,6 +117,33 @@ class TranslationTests {
         )
     }
 
+    /** For every translatable string and all translations check if all translated placeholders are present in the key */
+    @Test
+    fun allTranslationsHaveNoExtraPlaceholders() {
+        var allTranslationsHaveNoExtraPlaceholders = true
+        val languages = translations.getLanguages()
+        for ((key, translation) in translations) {
+            val translationEntry = translation.entry
+            val placeholders = squareBraceRegex.findAll(translationEntry)
+                .map { it.value }.toSet()
+            for (language in languages) {
+                val output = translations.getText(key, language)
+                if (output == key) continue // the language doesn't have the required translation, so we got back the key
+                val translatedPlaceholders = squareBraceRegex.findAll(output)
+                    .map { it.value }.toSet()
+                val extras = translatedPlaceholders - placeholders
+                for (placeholder in extras) {
+                    allTranslationsHaveNoExtraPlaceholders = false
+                    println("Extra placeholder `$placeholder` in `$language` for entry `$translationEntry`")
+                }
+            }
+        }
+        Assert.assertTrue(
+            "This test will only pass when all placeholders in all translations are present in the key",
+            allTranslationsHaveNoExtraPlaceholders
+        )
+    }
+
     @Test
     fun allPlaceholderKeysMatchEntry() {
         var allPlaceholderKeysMatchEntry = true
